@@ -2,22 +2,23 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ###############################################################################
 
-import time as time
-import numpy as np
-import matplotlib.pyplot as plt
-from financepy.utils.date import Date
-from financepy.utils.day_count import DayCountTypes
-from financepy.utils.frequency import FrequencyTypes
-from financepy.utils.calendar import CalendarTypes
-from financepy.products.rates.ibor_fra import IborFRA
-from financepy.products.rates.ibor_future import IborFuture
-from financepy.products.rates.ois import OIS
-from financepy.products.rates.ois_curve import OISCurve
-from financepy.products.rates.ibor_deposit import IborDeposit
-from financepy.utils.calendar import BusDayAdjustTypes
-from financepy.market.curves.interpolator import InterpTypes
-from financepy.utils.global_types import SwapTypes
 from FinTestCases import FinTestCases, globalTestCaseMode
+from financepy.utils.global_types import SwapTypes
+from financepy.market.curves.interpolator import InterpTypes
+from financepy.utils.calendar import BusDayAdjustTypes
+from financepy.products.rates.ibor_deposit import IborDeposit
+from financepy.products.rates.ois_curve import OISCurve
+from financepy.products.rates.ois import OIS
+from financepy.products.rates.ibor_future import IborFuture
+from financepy.products.rates.ibor_fra import IborFRA
+from financepy.utils.calendar import CalendarTypes
+from financepy.utils.frequency import FrequencyTypes
+from financepy.utils.day_count import DayCountTypes
+from financepy.utils.date import Date
+import matplotlib.pyplot as plt
+import numpy as np
+import time as time
+
 import sys
 sys.path.append("..")
 
@@ -131,7 +132,7 @@ def test_OISDepositsFRAsSwaps():
 #                        fixedDCCType)
 #    swaps.append(swap)
 
-    fixed_leg_type = SwapTypes.PAY
+    fixed_leg_type = Finfixed_leg_types.PAY
     maturity_date = settleDt.add_months(36)
     swap = OIS(settleDt, maturity_date, fixed_leg_type, swap_rate,
                fixedFreqType,
@@ -241,7 +242,7 @@ def test_OISDepositsFRAsSwaps():
 # https://github.com/vilen22/curve-building/blob/master/Bloomberg%20Curve%20Building%20Replication.xlsx
 ###############################################################################
 ###############################################################################
-# AGREEMENT IS VERY CLOSE - NOT SURE ABOUT SIZE OF LAST PAYMENT ON FIXED LEG!
+# AGREEEMENT IS VERY CLOSE - NOT SURE ABOUT SIZE OF LAST PAYMENT ON FIXED LEG!
 
 
 def futureToFRARate(price, convexity):
@@ -394,7 +395,7 @@ def test_derivativePricingExample():
     day_count_type = DayCountTypes.THIRTY_E_360_ISDA
 #    day_count_type = DayCountTypes.ACT_360
     freq_type = FrequencyTypes.SEMI_ANNUAL
-    fixed_leg_type = SwapTypes.PAY
+    fixed_leg_type = Finfixed_leg_types.PAY
 
     swap_rate = 0.0058
     swap = OIS(settleDt, "1Y", fixed_leg_type,
@@ -562,21 +563,22 @@ def test_bloombergPricingExample():
     oisCurve = OISCurve(valuation_date, depos, fras, swaps)
 
 #    swaps[0]._fixed_leg.print_valuation()
-#    swaps[0]._float_leg.print_valuation()
+#    swaps[0]._floatLeg.print_valuation()
 
     # The valuation of 53714.55 is very close to the spreadsheet value 53713.96
+    principal = 0.0
 
     testCases.header("VALUATION TO TODAY DATE", " PV")
     testCases.print("VALUE:", swaps[0].value(valuation_date, oisCurve, None))
     testCases.print(
         "FIXED:", -swaps[0]._fixed_leg.value(valuation_date, oisCurve))
-    testCases.print("FLOAT:", swaps[0]._float_leg.value(
+    testCases.print("FLOAT:", swaps[0]._floatLeg.value(
         valuation_date, oisCurve, None))
 
     testCases.header("VALUATION TO SWAP SETTLEMENT DATE", " PV")
     testCases.print("VALUE:", swaps[0].value(settleDt, oisCurve, None))
     testCases.print("FIXED:", -swaps[0]._fixed_leg.value(settleDt, oisCurve))
-    testCases.print("FLOAT:", swaps[0]._float_leg.value(
+    testCases.print("FLOAT:", swaps[0]._floatLeg.value(
         settleDt, oisCurve, None))
 
     # swaps[0].print_fixed_leg_pv()
