@@ -2,13 +2,13 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ###############################################################################
 
-from financepy.utils.calendar import BusDayAdjustTypes
-from financepy.utils.calendar import DateGenRuleTypes
-from financepy.utils.schedule import Schedule
-from financepy.utils.frequency import FrequencyTypes
-from financepy.utils.calendar import CalendarTypes, Calendar
-from financepy.utils.date import Date, set_date_format, DateFormatTypes
 from FinTestCases import FinTestCases, globalTestCaseMode
+from financepy.utils.date import Date, set_date_format, DateFormatTypes
+from financepy.utils.calendar import CalendarTypes, Calendar
+from financepy.utils.frequency import FrequencyTypes
+from financepy.utils.schedule import Schedule
+from financepy.utils.calendar import DateGenRuleTypes
+from financepy.utils.calendar import BusDayAdjustTypes
 import sys
 sys.path.append("..")
 
@@ -348,17 +348,9 @@ def test_FinScheduleAlignment(eomFlag):
                       adjust_termination_date,
                       eomFlag)
 
-#    print(sched1._adjusted_dates[-1])
-#    print(sched2._adjusted_dates[len(sched1._adjusted_dates)-1])
-
-# THIS TEST IS NO LONGER CORRECT AS I HAVE CHANGED THE  LOGIC TO STEP IN MULTIPLES
-
     compare = (
         sched1._adjusted_dates[-1] == sched2._adjusted_dates[len(sched1._adjusted_dates)-1])
-
-
-#    print(compare, eomFlag)
-#    assert(compare == eomFlag)
+    assert(compare == eomFlag)
 
 ###############################################################################
 
